==> 0.1.0.zip: exml/exml/Text.h <==
/**
 * @author Edouard DUPIN
 * 
 * @copyright 2011, Edouard DUPIN, all right reserved
 * 
 * @license BSD v3 (see license file)
 */

#ifndef __ETK_XML_TEXT_H__
#define __ETK_XML_TEXT_H__

#include <exml/Node.h>
#include <vector>

namespace exml {
	class Text : public exml::Node {
		public:
			/**
			 * @brief Constructor
			 */
			Text(void) { };
			/**
			 * @brief Constructor
			 * @param[in] _data String data of the current Text
			 */
			Text(const std::string& _data) : exml::Node(_data) { };
			/**
			 * @brief Destructor
			 */
			virtual ~Text(void) { };
			/**
			 * @brief count the number of line in the current text
			 * @return The number of lines
			 */
			int32_t countLines(void) const;
		public: // herited function:
			virtual enum nodeType getType(void) const {
				return typeText;
			};
			virtual bool iParse(const std::string& _data, int32_t& _pos, bool _caseSensitive, exml::filePos& _filePos, exml::Document& _doc);
			virtual bool iGenerate(std::string& _data, int32_t _indent) const;
			virtual exml::Text* toText(void) {
				return this;
			};
			virtual const exml::Text* toText(void) const{
				return this;
			};
	};
	class TextCDATA : public exml::Text {
		public:
			/**
			 * @brief Constructor
			 */
			TextCDATA(void) { };
			/**
			 * @brief Destructor
			 */
			virtual ~TextCDATA(void) { };
		public: // herited function:
			virtual bool iParse(const std::string& _data, int32_t& _pos, bool _caseSensitive, exml::filePos& _filePos, exml::Document& _doc);
	};
};


#endif

==> 0.3.0.zip: exml/exml/Text.h <==
/**
 * @author Edouard DUPIN
 * 
 * @copyright 2011, Edouard DUPIN, all right reserved
 * 
 * @license APACHE v2.0 (see license file)
 */

#ifndef __ETK_XML_TEXT_H__
#define __ETK_XML_TEXT_H__

#include <exml/Node.h>
#include <vector>

namespace exml {
	class Text : public exml::Node {
		public:
			/**
			 * @brief Constructor
			 */
			Text() { };
			/**
			 * @brief Constructor
			 * @param[in] _data String data of the current Text
			 */
			Text(const std::string& _data) : exml::Node(_data) { };
			/**
			 * @brief Destructor
			 */
			virtual ~Text() { };
			/**
			 * @brief count the number of line in the current text
			 * @return The number of lines
			 */
			int32_t countLines() const;
		public: // herited function:
			virtual enum nodeType getType() const {
				return typeText;
			};
			virtual bool iParse(const std::string& _data, int32_t& _pos, bool _caseSensitive, exml::filePos& _filePos, exml::Document& _doc);
			virtual bool iGenerate(std::string& _data, int32_t _indent) const;
			virtual exml::Text* toText() {
				return this;
			};
			virtual const exml::Text* toText() const{
				return this;
			};
	};
	class TextCDATA : public exml::Text {
		public:
			/**
			 * @brief Constructor
			 */
			TextCDATA() { };
			/**
			 * @brief Destructor
			 */
			virtual ~TextCDATA() { };
		public: // herited function:
			virtual bool iParse(const std::string& _data, int32_t& _pos, bool _caseSensitive, exml::filePos& _filePos, exml::Document& _doc);
			virtual bool iGenerate(std::string& _data, int32_t _indent) const;
	};
};


#endif
